"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getVueDoc;

var _path = _interopRequireDefault(require("path"));

var _variables = require("./variables");

var _processTags = _interopRequireDefault(require("./processTags"));

var _processProps = _interopRequireDefault(require("./processProps"));

var _processMethods = _interopRequireDefault(require("./processMethods"));

var _processEvents = _interopRequireDefault(require("./processEvents"));

function getVueDoc(stateDoc, component) {
  let docJsFile = stateDoc.getDocJs();
  let docComponent;
  const displayName = !component.name || component.name === '' // if component does not have a name, use the name of the file containing it
  ? _path.default.basename(stateDoc.file, _path.default.extname(stateDoc.file)) : component.name;

  if (docJsFile) {
    docJsFile = docJsFile.filter(comment => {
      return comment.kind !== 'package';
    });
    docComponent = docJsFile.filter(comment => {
      return comment.longname === 'module.exports' || comment.longname.match(/(_)?default(\d+)?$/g);
    })[0];
  } else {
    docJsFile = [];
    docComponent = false;
  }

  let description = _variables.EMPTY;
  let comment = _variables.EMPTY;
  let tags = {};

  if (docComponent) {
    description = (0, _variables.getDescription)(docComponent);
    comment = (0, _variables.getComment)(docComponent);
    tags = (0, _processTags.default)(docComponent, _variables.IGNORE_DEFAULT);
  }

  const props = (0, _processProps.default)(docJsFile, component);
  const methods = (0, _processMethods.default)(docJsFile, component);
  const events = (0, _processEvents.default)(docJsFile, component);
  return {
    description,
    methods,
    displayName,
    props,
    comment,
    tags,
    events,
    slots: stateDoc.slots
  };
}