"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _parser = _interopRequireDefault(require("./parser"));

var _getComponentModuleJSCode = _interopRequireDefault(require("./getComponentModuleJSCode"));

var _getSlots = _interopRequireDefault(require("./getSlots"));

var _getDocFile = _interopRequireDefault(require("./getDocFile"));

class stateDoc {
  constructor() {
    this.file = '';
    this.docComponent = {};
    this.sourceComponent = '';
    this.docMixins = [];
    this.jscodeRequest = '';
    this.jscodeLang = undefined;
    this.docTemp = '';
    this.slots;
  }

  isMainComponent(file) {
    return file === this.file;
  }

  saveComponent(source, file) {
    if (this.isMainComponent(file) && this.sourceComponent !== source) {
      const parts = (0, _parser.default)(source, 'name');
      this.slots = (0, _getSlots.default)(parts);
      this.docComponent = [];

      if (parts.script) {
        this.jscodeRequest = (0, _getComponentModuleJSCode.default)(parts, source, file);
        this.jscodeLang = parts.script.lang;
        this.docComponent = this.getDocFile(this.jscodeRequest, file, this.jscodeLang);
      }
    }
  }

  getDocFile(source, file, lang) {
    this.docTemp = (0, _getDocFile.default)(source, file, lang);
    return this.docTemp;
  }

  isMixin(doc) {
    doc = doc || this.docTemp;
    return doc.some(docPart => {
      return docPart.kind === 'mixin';
    });
  }

  getDocJs() {
    let docMixins = [].concat.apply([], this.docMixins).filter(function (docPart) {
      return docPart.kind !== 'package';
    });
    return this.docComponent.concat(docMixins);
  }

  saveMixin(doc, file) {
    if (this.isMixin(doc)) {
      doc = doc.map(docPart => {
        let longnameSplit = docPart.longname.split('.');

        if (longnameSplit[0] === 'default') {
          longnameSplit[0] = 'module.exports';
        }

        docPart.longname = longnameSplit.join('.');
        return docPart;
      }).filter(docPart => {
        return docPart.longname !== 'module.exports';
      });
      let index;
      this.docMixins.forEach((docMixin, id) => {
        const packages = docMixin.filter(function (docPart) {
          return docPart.kind === 'package';
        })[0];

        if (packages && packages.files[0] === file) {
          index = id;
        }
      });

      if (!index) {
        this.docMixins.unshift(doc);
      }
    }
  }

  reset() {
    this.file = '';
    this.docComponent = {};
    this.sourceComponent = '';
    this.docMixins = [];
    this.jscodeRequest = '';
    this.jscodeLang = undefined;
    this.docTemp = '';
  }

}

var _default = new stateDoc();

exports.default = _default;